==> zio-aws-cloudfront_2.13-5.17.104.13-sources.jar: zio/aws/cloudfront/model/ContentTypeProfiles.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cloudfront.model.primitives.Integer
import scala.jdk.CollectionConverters._
final case class ContentTypeProfiles(
    quantity: Integer,
    items: Option[Iterable[zio.aws.cloudfront.model.ContentTypeProfile]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.ContentTypeProfiles = {
    import ContentTypeProfiles.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.ContentTypeProfiles
      .builder()
      .quantity(Integer.unwrap(quantity): java.lang.Integer)
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.ContentTypeProfiles.ReadOnly =
    zio.aws.cloudfront.model.ContentTypeProfiles.wrap(buildAwsValue())
}
object ContentTypeProfiles {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.ContentTypeProfiles
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.ContentTypeProfiles =
      zio.aws.cloudfront.model.ContentTypeProfiles(
        quantity,
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def quantity: Integer
    def items
        : Option[List[zio.aws.cloudfront.model.ContentTypeProfile.ReadOnly]]
    def getQuantity: ZIO[Any, Nothing, Integer] = ZIO.succeed(quantity)
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.cloudfront.model.ContentTypeProfile.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.ContentTypeProfiles
  ) extends zio.aws.cloudfront.model.ContentTypeProfiles.ReadOnly {
    override val quantity: Integer =
      zio.aws.cloudfront.model.primitives.Integer(impl.quantity())
    override val items
        : Option[List[zio.aws.cloudfront.model.ContentTypeProfile.ReadOnly]] =
      scala
        .Option(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.cloudfront.model.ContentTypeProfile.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.ContentTypeProfiles
  ): zio.aws.cloudfront.model.ContentTypeProfiles.ReadOnly = new Wrapper(impl)
}

==> zio-aws-cloudfront_2.13-5.17.158.1-sources.jar: zio/aws/cloudfront/model/ContentTypeProfiles.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cloudfront.model.primitives.Integer
import scala.jdk.CollectionConverters._
final case class ContentTypeProfiles(
    quantity: Integer,
    items: Option[Iterable[zio.aws.cloudfront.model.ContentTypeProfile]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.ContentTypeProfiles = {
    import ContentTypeProfiles.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.ContentTypeProfiles
      .builder()
      .quantity(quantity: java.lang.Integer)
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.ContentTypeProfiles.ReadOnly =
    zio.aws.cloudfront.model.ContentTypeProfiles.wrap(buildAwsValue())
}
object ContentTypeProfiles {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.ContentTypeProfiles
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.ContentTypeProfiles =
      zio.aws.cloudfront.model.ContentTypeProfiles(
        quantity,
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def quantity: Integer
    def items
        : Option[List[zio.aws.cloudfront.model.ContentTypeProfile.ReadOnly]]
    def getQuantity: ZIO[Any, Nothing, Integer] = ZIO.succeed(quantity)
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.cloudfront.model.ContentTypeProfile.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.ContentTypeProfiles
  ) extends zio.aws.cloudfront.model.ContentTypeProfiles.ReadOnly {
    override val quantity: Integer = impl.quantity(): Integer
    override val items
        : Option[List[zio.aws.cloudfront.model.ContentTypeProfile.ReadOnly]] =
      scala
        .Option(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.cloudfront.model.ContentTypeProfile.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.ContentTypeProfiles
  ): zio.aws.cloudfront.model.ContentTypeProfiles.ReadOnly = new Wrapper(impl)
}
